@@ -40,9 +40,9 @@
 
 /* Usefull in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-2.8.7/gdcm-2.8.7"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-2.8.7/build-arm/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-2.8.7/build-arm/bin"
+#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-2.8.9/gdcm-2.8.9"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-2.8.9/build-amd64/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-2.8.9/build-amd64/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -117,6 +117,7 @@
 /* #undef GDCM_HAVE__SNPRINTF */
 #define GDCM_HAVE_LROUND
 #define GDCM_HAVE_GETTIMEOFDAY
+#define GDCM_HAVE_ATOLL
 #define GDCM_HAVE_JSON_OBJECT_OBJECT_GET_EX
 
 // MM: I have a feeling that if GDCM_HAVE_WCHAR_IFSTREAM, then UNICODE filename
@@ -146,8 +147,8 @@
 /* Version number.  */
 #define GDCM_MAJOR_VERSION 2
 #define GDCM_MINOR_VERSION 8
-#define GDCM_BUILD_VERSION 7
-#define GDCM_VERSION "2.8.7"
+#define GDCM_BUILD_VERSION 9
+#define GDCM_VERSION "2.8.9"
 #define GDCM_API_VERSION "2.8"
 
 /*
